@@ -1,12 +1,31 @@
 import time
 from dataclasses import asdict, dataclass, field, fields
-from enum import Enum
+from enum import Enum, StrEnum
 from functools import wraps
 from typing import Any, Callable, Protocol, Self, Tuple, Type, TypeVar, cast
 
 from dacite import Config, from_dict
 
 
+class KastFormat(StrEnum):
+    AVRO = "avro"
+    JSON = "json"
+    CSV = "csv"
+    PARQUET = "parquet"
+
+    @staticmethod
+    def unmarshal(format: str) -> "KastFormat":
+        try:
+            return KastFormat(format)
+        except ValueError as e:
+            raise KastFunctionInvalidArgumentsException(
+                message=[
+                    ["KastFormat", f"shoud be one of {list(map(str, KastFormat))}"],
+                ],
+                errors=e,
+            )
+
+
 class KastDataFrameBackend(Enum):
     NOTSET = "notset"
     PANDAS = "pandas"
@@ -108,6 +127,7 @@ class KastTool(Protocol):
     def newKastDataFrame(
         self: Self,
         df: Any,
+        schema: str = "",
     ) -> KastDataFrame:
         ...
 
